@@ -77,11 +77,6 @@ describe 'nova::compute' do
         is_expected.to contain_package('genisoimage').that_requires('Anchor[nova::install::begin]')
         is_expected.to contain_package('genisoimage').that_comes_before('Anchor[nova::install::end]')
       end
-
-      it 'configures nova pci_passthrough_whitelist' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
-      end
     end
 
     context 'with overridden parameters' do
@@ -187,56 +182,6 @@ describe 'nova::compute' do
       end
     end
 
-    context 'with pci params array' do
-      let :params do
-        {
-          :pci_passthrough => [
-            {
-              "vendor_id"  => "8086",
-              "product_id" => "0126"
-            },
-            {
-              "vendor_id"        => "9096",
-              "product_id"       => "1520",
-              "physical_network" => "physnet1"
-            }
-          ],
-        }
-      end
-
-      it 'configures nova pci_passthrough_whitelist entries' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
-        )
-      end
-    end
-
-    context 'with pci params JSON encoded string (deprecated)' do
-      let :params do
-        {
-          :pci_passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
-        }
-      end
-
-      it 'configures nova pci_passthrough_whitelist entries' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
-        )
-      end
-    end
-
-    context 'when vcpu_pin_set and pci params are empty' do
-      let :params do
-        { :pci_passthrough => ""}
-      end
-      it 'clears pci_passthrough configuration' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
-      end
-    end
-
     context 'with reserved_huge_pages array' do
       let :params do
         {
@@ -267,7 +212,7 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '4-12,^8,15') }
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with(:value => '2-10,^5,14') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:ensure => 'absent') }
+      it { is_expected.to contain_nova_config('compute/vcpu_pin_set').with(:ensure => 'absent') }
     end
 
     context 'when cpu_dedicated_set is defined but cpu_shared_set is not' do
@@ -277,7 +222,7 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with(:value => '4-12,^8,15') }
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:ensure => 'absent') }
+      it { is_expected.to contain_nova_config('compute/vcpu_pin_set').with(:ensure => 'absent') }
     end
 
     context 'when cpu_shared_set is defined, but cpu_dedicated_set and vcpu_pin_set are not' do
@@ -287,7 +232,7 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '4-12,^8,15') }
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with(:value => '<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:ensure => 'absent') }
+      it { is_expected.to contain_nova_config('compute/vcpu_pin_set').with(:ensure => 'absent') }
     end
 
     context 'when cpu_shared_set and vcpu_pin_set are defined, but cpu_dedicated_set is not' do
@@ -297,7 +242,7 @@ describe 'nova::compute' do
       end
 
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '4-12,^8,15') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '2-10,^5,14') }
+      it { is_expected.to contain_nova_config('compute/vcpu_pin_set').with(:value => '2-10,^5,14') }
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with(:value => '<SERVICE DEFAULT>') }
     end
 
@@ -306,7 +251,7 @@ describe 'nova::compute' do
          { :vcpu_pin_set => ['4-12','^8','15'] }
       end
 
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with(:value => '4-12,^8,15') }
+      it { is_expected.to contain_nova_config('compute/vcpu_pin_set').with(:value => '4-12,^8,15') }
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with(:value => '<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with(:value => '<SERVICE DEFAULT>') }
     end
@@ -356,7 +301,7 @@ describe 'nova::compute' do
           :spice_enabled => true, }
       end
 
-      it { is_expected.to raise_error Puppet::Error, /vnc_enabled and spice_enabled is mutually exclusive/ }
+      it { should raise_error(Puppet::Error, /vnc_enabled and spice_enabled is mutually exclusive/) }
     end
 
     context 'with force_config_drive parameter set to true' do
